@@ -2,7 +2,7 @@
 # vc-dwim - a version-control-agnostic ChangeLog diff and commit tool
 # @configure_input@
 #
-# Copyright 2006-2010 Free Software Foundation, Inc.
+# Copyright 2006-2011 Free Software Foundation, Inc.
 # Written by Jim Meyering <meyering@redhat.com>
 
 # This program is free software: you can redistribute it and/or modify
@@ -31,37 +31,6 @@
 use strict;
 use warnings;
 
-package PodTemplate;
-use Pod::PlainText;
-our @ISA = qw(Pod::PlainText);
-
-sub new
-{
-  my $this = shift;
-  my $class = ref($this) || $this;
-  my %params = @_;
-  my $self = { %params };
-  bless $self, $class;
-  $self->initialize();
-  return $self;
-}
-
-sub _lookup($$)
-{
-  my ($dict, $word) = @_;
-  return exists $dict->{$word} ? $dict->{$word} : $word;
-}
-
-sub preprocess_paragraph
-{
-  my ($self, $text) = @_;
-  $text =~ s/\@\@(.*?)\@\@/_lookup($self->{dict},$1)/eg;
-  return $text;
-}
-
-
-package main;
-
 use Getopt::Long;
 use File::Basename; # for basename and dirname
 
@@ -83,6 +52,7 @@ BEGIN
 use Coda;
 use VC;
 use ProcessStatus qw($PROCESS_STATUS process_status);
+use Pod::PlainText;
 
 our $VERSION = '@VERSION@';
 (my $ME = $0) =~ s|.*/||;
@@ -100,7 +70,7 @@ sub usage ($)
     }
   else
     {
-      my $parser = PodTemplate->new (sentence => 1, width => 78,
+      my $parser = Pod::PlainText->new (sentence => 1, width => 78,
                                      dict => {ME => $ME});
       # Read POD from __END__ (below) and write to STDOUT.
       *STDIN = *DATA;
@@ -1076,25 +1046,25 @@ __END__
 
 =head1  NAME
 
-@@ME@@ - use new ChangeLog entries to direct and cross-check a
+vc-dwim - use new ChangeLog entries to direct and cross-check a
 version-control "diff" or "commit" command
 
 =head1  SYNOPSIS
 
-B<@@ME@@> [OPTIONS] [CHANGELOG_FILE...]
+B<vc-dwim> [OPTIONS] [CHANGELOG_FILE...]
 
-B<@@ME@@> [OPTIONS] --commit CHANGELOG_FILE...
+B<vc-dwim> [OPTIONS] --commit CHANGELOG_FILE...
 
-B<@@ME@@> [OPTIONS] --diff [FILE...]
+B<vc-dwim> [OPTIONS] --diff [FILE...]
 
-B<@@ME@@> [OPTIONS] --print-vc-list
+B<vc-dwim> [OPTIONS] --print-vc-list
 
 =head1  DESCRIPTION
 
 By default, each command line argument should be a locally modified,
 version-controlled ChangeLog file.  If there is no command line argument,
-B<@@ME@@> tries to use the ChangeLog file in the current directory.
-In this default mode, B<@@ME@@> works by first computing diffs of those
+B<vc-dwim> tries to use the ChangeLog file in the current directory.
+In this default mode, B<vc-dwim> works by first computing diffs of those
 files and parsing the
 diff output to determine which named files are being changed.
 Then, it diffs the affected files and prints the resulting output.  One
@@ -1104,7 +1074,7 @@ It detects that by searching for an editor temporary file corresponding
 to each affected file.  Another common error you can avoid with this
 tool is the one where you create a new file, add its name to Makefiles,
 etc., mention the addition in ChangeLog, but forget to e.g., "git add"
-(or "hg add", etc.) the file to the version control system.  B<@@ME@@>
+(or "hg add", etc.) the file to the version control system.  B<vc-dwim>
 detects this discrepancy and fails with a diagnostic explaining the
 probable situation.  You might also have simply mistyped the file name
 in the ChangeLog.
@@ -1113,7 +1083,7 @@ Once you are happy with your ChangeLog-derived diffs, you can commit
 those changes and the ChangeLog simply by rerunning the command with
 the --commit option.
 
-But what if you'd like to use B<@@ME@@> on a project that doesn't have
+But what if you'd like to use B<vc-dwim> on a project that doesn't have
 or want a ChangeLog file?  In that case, you can maintain your own,
 private, version-controlled ChangeLog file in a different hierarchy.
 Then just make a symlink to it from the top level directory of the
@@ -1165,7 +1135,7 @@ Generate debug output.
 
 =head1  EXAMPLE
 
-Here's how to use B<@@ME@@> in a project that does not version-control
+Here's how to use B<vc-dwim> in a project that does not version-control
 a ChangeLog file.  Create a repository just for your personal
 ChangeLog file and make a symlink to it from the top-level directory
 of the project.  For projects that use git, I put this tiny
